package com.xinyilu.system.mapper.systemarea;

import com.xinyilu.system.domain.systemarea.SysArea;
import com.xinyilu.system.domain.vo.sysarea.AreaInfoVO;

import java.util.List;


/**
 * 区域管理Mapper接口
 *
 * @author jihan
 * @date 2022-07-27
 */
public interface SysAreaMapper {
    /**
     * 查询区域管理
     *
     * @param id 区域管理主键
     * @return 区域管理
     */
    public SysArea selectSysAreaById(Long id);

    /**
     * 查询区域管理列表
     *
     * @param sysArea 区域管理
     * @return 区域管理集合
     */
    public List<SysArea> selectSysAreaList(SysArea sysArea);

    /**
     * 新增区域管理
     *
     * @param sysArea 区域管理
     * @return 结果
     */
    public int insertSysArea(SysArea sysArea);

    /**
     * 修改区域管理
     *
     * @param sysArea 区域管理
     * @return 结果
     */
    public int updateSysArea(SysArea sysArea);

    /**
     * 删除区域管理
     *
     * @param id 区域管理主键
     * @return 结果
     */
    public int deleteSysAreaById(Long id);

    /**
     * 批量删除区域管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysAreaByIds(Long[] ids);

    /**
     * 根据区域编码查询区域信息
     *
     * @param code 区域编码
     * @return int 数量
     */
    int getSysAreaByCodeAndName(String code);

    /**
     * 查询省市区域管理列表
     *
     * @param sysArea 区域管理
     * @return 区域管理集合
     */
    List<SysArea> getCityAreaInfoList(SysArea sysArea);

    /**
     * 根据区域id获取省市区信息
     *
     * @param id 区域id
     * @return 区域信息
     */
    AreaInfoVO getThreeAreaInfo(Long id);

    /**
     * 根据区域id获取省市信息
     *
     * @param id 区域id
     * @return 区域信息
     */
    AreaInfoVO getSecondAreaInfo(Long id);

    /**
     * 根据父id查询下属区域信息
     *
     * @param parentId 父id
     * @return 下属区域id集合
     */
    List<Long> getSysAreaIdList(Long parentId);

    /**
     * 根据父id查询下属区域信息
     *
     * @param parentId 父id
     * @return 下属区域id集合
     */
    List<SysArea> getSubordinateSysAreaIdList(Long parentId);
}
